<?php declare(strict_types=1);

namespace App\Helpers;

use Illuminate\Support\Number as LaravelNumber;

final readonly class Number
{
    private const array ABBREVIATE_UNITS = [
        3  => 'K',
        6  => 'M',
        9  => 'B',
        12 => 'T',
        15 => 'Q',
    ];

    /**
     * Convert the number to its human-readable equivalent.
     *
     * @param int|float $number
     * @return string
     */
    public static function abbreviate(int|float $number): string
    {
        if ($number < 0) {
            throw new \InvalidArgumentException('Number cannot be negative');
        }

        return self::summarize($number);
    }

    /**
     * $size - Size in bytes
     * @param int $size
     *
     * @return string
     */
    public static function sizeForHumans(int $size): string
    {
        return LaravelNumber::fileSize($size);
    }

    private static function summarize(int|float $number, bool $hidePlusSymbol = false): string
    {
        $symbol = '+';
        if ($hidePlusSymbol) {
            $symbol = '';
        }

        if ($number < 1000) {
            return (string) $number;
        }

        if ($number >= 1e15) {
            $units = self::ABBREVIATE_UNITS;
            return sprintf('%s' . end($units), self::summarize($number / 1e15, hidePlusSymbol: true)) . $symbol;
        }

        $numberExponent = \floor(\log10($number));
        $displayExponent = $numberExponent - ($numberExponent % 3);
        $number /= \pow(10, $displayExponent);
        $number = \explode('.', (string) $number, 2);

        $remainder = $number[1] ?? 0;
        $number    = $number[0] ?? 0;

        if ($remainder === 0) {
            $symbol = '';
        }
        $abbreviated = self::ABBREVIATE_UNITS[$displayExponent] ?? '';

        return (string) $number . $abbreviated . $symbol;
    }
}
