<?php declare(strict_types=1);

namespace App\Http\Requests\Site\AccessTokens;

use App\Contracts\FormRequestDto;
use App\Dto\Service\Site\AccessTokens\StoreUpdate;
use App\Enums\AccessTokenPermission;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Validation\Rules\Enum;

final class StoreUpdateRequest extends FormRequest implements FormRequestDto
{
    /**
     * Get the validation rules that apply to the request.
     */
    public function rules(): array
    {
        return [
            'name'        => ['required', 'string', 'max:255'],
            'permissions' => ['required', 'string', new Enum(AccessTokenPermission::class)],
        ];
    }


    public function getDto(): StoreUpdate
    {
        return new StoreUpdate(
            name: $this->input('name'),
            permission: AccessTokenPermission::from(
                $this->input('permissions')
            ),
        );
    }
}
