<?php declare(strict_types=1);

namespace App\Http\Requests\Site\Repositories;

use App\Contracts\FormRequestDto;
use App\Dto\Service\Site\Repository\StoreUpdate;
use App\Rules\Repository;
use Illuminate\Foundation\Http\FormRequest;

final class StoreUpdateRequest extends FormRequest implements FormRequestDto
{
    /**
     * Get the validation rules that apply to the request.
     */
    public function rules(): array
    {
        $rules = [
            'description' => ['nullable', 'string', 'max:300'],
            'overview'    => ['nullable', 'string'],
            'is_public'   => ['required', 'boolean'],
        ];

        if ($this->getMethod() === 'POST') {
            $rules['name'] = ['required', 'string', new Repository()];
        }

        return $rules;
    }


    public function getDto(): StoreUpdate
    {
        return new StoreUpdate(
            isPublic: (bool) $this->input('is_public', false),
            description: $this->input('description'),
            overview: $this->input('overview'),
            name: $this->input('name'),
        );
    }
}
