<?php declare(strict_types=1);

namespace App\Jobs\Registry\V2;

use App\Dto\Service\Registry\V2\EventService\ImageDataPull;
use App\Exceptions\Jobs\Registry\V2\JobException;
use App\Services\Registry\V2\EventService;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldBeEncrypted;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;

final class ProcessEventPull implements ShouldQueue, ShouldBeEncrypted
{
    use Dispatchable, InteractsWithQueue, Queueable, SerializesModels;

    /**
     * Create a new job instance.
     */
    public function __construct(
        public readonly array $target
    ) {
        //
    }

    /**
     * Execute the job.
     */
    public function handle(EventService $eventService): void
    {
        if (!isset($this->target['tag'])) {
            return;
        }

        [$username, $repositoryName] = \explode('/', $this->target['repository'], 2);

        $data = new ImageDataPull(
            username:       $username,
            repositoryName: $repositoryName,
            tag:            $this->target['tag'],
            digest:         $this->target['digest'],
        );
        $result = $eventService->pull($data);
        if ($result->isError()) {
            throw new JobException($result->getMessage());
        }
    }

    /**
     * Calculate the number of seconds to wait before retrying the job.
     *
     * @return array<int, int>
     */
    public function backoff(): array
    {
        return [10, 60, 600, 1800, 3600];
    }
}
