<?php declare(strict_types=1);

namespace App\Policies;

use App\Enums\AccessTokenPermission;
use App\Models\Repository;
use App\Models\User;
use Laravel\Sanctum\Contracts\HasAbilities;

final readonly class RepositoryPolicy extends Policy
{
    public function create(User $user, User $repositoryUser): bool
    {
        return $user->id === $repositoryUser->id;
    }

    public function view(User $user, Repository $repository): bool
    {
        if ($repository->is_public) {
            return true;
        }

        return $user->id === $repository->user_id;
    }

    public function update(User $user, Repository $repository): bool
    {
        return $user->id === $repository->user_id;
    }

    public function delete(User $user, Repository $repository): bool
    {
        return $user->id === $repository->user_id;
    }

    public function pull(User $user, Repository $repository): bool
    {
        if ($repository->is_public) {
            return true;
        }

        if ($repository->user_id !== $user->id) {
            return false;
        }

        if ($user->currentAccessToken()) {
            return $this->tokenCan(
                [
                    AccessTokenPermission::RepoReadWriteDelete->value,
                    AccessTokenPermission::RepoReadWrite->value,
                    AccessTokenPermission::RepoRead->value,
                ],
                $user->currentAccessToken()
            );
        }

        return true;
    }

    public function push(User $user, Repository $repository): bool
    {
        if ($repository->user_id !== $user->id) {
            return false;
        }

        if ($user->currentAccessToken()) {
            return $this->tokenCan(
                [
                    AccessTokenPermission::RepoReadWriteDelete->value,
                    AccessTokenPermission::RepoReadWrite->value,
                ],
                $user->currentAccessToken()
            );
        }

        return true;
    }

    private function tokenCan(array $permissions, HasAbilities $abilities): bool
    {
        foreach ($permissions as $permission) {
            if ($abilities->can($permission)) {
                return true;
            }
        }

        return false;
    }
}
