<?php declare(strict_types=1);

namespace App\Services\Registry\V2\Api;

use Illuminate\Http\Client\PendingRequest;
use Illuminate\Support\Facades\Http;

final readonly class RequestCommandHandler
{
    public function __construct(
        private string $baseUrl,
    ) { }

    public function handleGet(string $path, string $token): array
    {
        $response = $this->beforeRequest($token)->get($path);

        return $response->json();
    }

    private function beforeRequest(string $token): PendingRequest
    {
        return Http::withHeaders([
                'Accept'        => 'application/vnd.docker.distribution.manifest.v2+json',
                'Authorization' => 'Bearer ' . $token
            ])
            ->timeout(15)
            ->acceptJson()
            ->baseUrl($this->baseUrl);
    }
}
